@@ -24,10 +24,6 @@ import cachetools
 import numpy
 import pandas as pd
 from cachetools import TTLCache
-from gs_quant.target.common import FieldFilterMap, XRef, MarketDataVendor, PricingLocation
-from gs_quant.target.coordinates import MDAPIDataBatchResponse, MDAPIDataQuery, MDAPIDataQueryResponse, MDAPIQueryField
-from gs_quant.target.data import DataQuery, DataQueryResponse
-from gs_quant.target.data import DataSetEntity
 
 from gs_quant.api.data import DataApi
 from gs_quant.base import Base
@@ -35,8 +31,12 @@ from gs_quant.data.core import DataContext, DataFrequency
 from gs_quant.errors import MqValueError
 from gs_quant.markets import MarketDataCoordinate
 from gs_quant.session import GsSession
-from .assets import GsAssetApi, GsIdType
-from ...target.assets import EntityQuery
+from gs_quant.target.common import MarketDataVendor, PricingLocation
+from gs_quant.target.coordinates import MDAPIDataBatchResponse, MDAPIDataQuery, MDAPIDataQueryResponse, MDAPIQueryField
+from gs_quant.target.data import DataQuery, DataQueryResponse
+from gs_quant.target.data import DataSetEntity
+from .assets import GsIdType
+from ...target.assets import EntityQuery, FieldFilterMap
 
 _logger = logging.getLogger(__name__)
 
@@ -75,30 +75,50 @@ class QueryType(Enum):
     CENTRAL_BANK_SWAP_RATE = "Central Bank Swap Rate"
     FORWARD_PRICE = "Forward Price"
     FAIR_PRICE = "Fair Price"
+    PNL = "Pnl"
     SPOT = "Spot"
-    ES_NUMERIC_SCORE = "ES Numeric Score"
-    ES_NUMERIC_PERCENTILE = "ES Numeric Percentile"
-    ES_POLICY_SCORE = "ES Policy Score"
-    ES_POLICY_PERCENTILE = "ES Policy Percentile"
-    ES_SCORE = "ES Score"
-    ES_PERCENTILE = "ES Percentile"
+    ES_NUMERIC_SCORE = "Es Numeric Score"
+    ES_NUMERIC_PERCENTILE = "Es Numeric Percentile"
+    ES_POLICY_SCORE = "Es Policy Score"
+    ES_POLICY_PERCENTILE = "Es Policy Percentile"
+    ES_SCORE = "Es Score"
+    ES_PERCENTILE = "Es Percentile"
+    ES_PRODUCT_IMPACT_SCORE = "Es Product Impact Score"
+    ES_PRODUCT_IMPACT_PERCENTILE = "Es Product Impact Percentile"
     G_SCORE = "G Score"
     G_PERCENTILE = "G Percentile"
-    ES_MOMENTUM_SCORE = "ES Momentum Score"
-    ES_MOMENTUM_PERCENTILE = "ES Momentum Percentile"
+    ES_MOMENTUM_SCORE = "Es Momentum Score"
+    ES_MOMENTUM_PERCENTILE = "Es Momentum Percentile"
     G_REGIONAL_SCORE = "G Regional Score"
     G_REGIONAL_PERCENTILE = "G Regional Percentile"
-    ES_DISCLOSURE_PERCENTAGE = "ES Disclosure Percentage"
+    ES_DISCLOSURE_PERCENTAGE = "Es Disclosure Percentage"
+    CONTROVERSY_SCORE = "Controversy Score"
+    CONTROVERSY_PERCENTILE = "Controversy Percentile"
     RATING = "Rating"
     CONVICTION_LIST = "Conviction List"
-    GIR_GSDEER_GSFEER = "Gir Gsdeer Gsfeer"
-    GIR_FX_FORECAST = "Gir Fx Forecast"
+    FAIR_VALUE = "Fair Value"
+    FX_FORECAST = "Fx Forecast"
     GROWTH_SCORE = "Growth Score"
     FINANCIAL_RETURNS_SCORE = "Financial Returns Score"
     MULTIPLE_SCORE = "Multiple Score"
     INTEGRATED_SCORE = "Integrated Score"
-    GIR_COMMODITIES_FORECAST = "Gir Commodities Forecast"
+    COMMODITY_FORECAST = "Commodity Forecast"
     FORECAST_VALUE = "Forecast Value"
+    FCI = "Fci"
+    LONG_RATES_CONTRIBUTION = "Long Rates Contribution"
+    SHORT_RATES_CONTRIBUTION = "Short Rates Contribution"
+    CORPORATE_SPREAD_CONTRIBUTION = "Corporate Spread Contribution"
+    SOVEREIGN_SPREAD_CONTRIBUTION = "Sovereign Spread Contribution"
+    EQUITIES_CONTRIBUTION = "Equities Contribution"
+    REAL_LONG_RATES_CONTRIBUTION = "Real Long Rates Contribution"
+    REAL_SHORT_RATES_CONTRIBUTION = "Real Short Rates Contribution"
+    REAL_FCI = "Real Fci"
+    DWI_CONTRIBUTION = "Dwi Contribution"
+    REAL_TWI_CONTRIBUTION = "Real Twi Contribution"
+    TWI_CONTRIBUTION = "Twi Contribution"
+    COVARIANCE = "Covariance"
+    FACTOR_EXPOSURE = "Factor Exposure"
+    FACTOR_RETURN = "Factor Return"
 
 
 class GsDataApi(DataApi):
@@ -111,7 +131,7 @@ class GsDataApi(DataApi):
     @classmethod
     def query_data(cls, query: Union[DataQuery, MDAPIDataQuery], dataset_id: str = None,
                    asset_id_type: Union[GsIdType, str] = None) \
-            -> Union[MDAPIDataBatchResponse, DataQueryResponse, tuple]:
+            -> Union[MDAPIDataBatchResponse, DataQueryResponse, tuple, list]:
         if isinstance(query, MDAPIDataQuery) and query.market_data_coordinates:
             # Don't use MDAPIDataBatchResponse for now - it doesn't handle quoting style correctly
             results: Union[MDAPIDataBatchResponse, dict] = cls.execute_query('coordinates', query)
@@ -119,49 +139,8 @@ class GsDataApi(DataApi):
                 return results.get('responses', ())
             else:
                 return results.responses if results.responses is not None else ()
-        elif isinstance(query, DataQuery) and query.where:
-            where = query.where.as_dict() if isinstance(query.where, FieldFilterMap) else query.where
-            xref_keys = set(where.keys()).intersection(XRef.properties())
-            if xref_keys:
-                # Check that assetId is a symbol dimension of this data set. If not, we need to do a separate query
-                # to resolve xref pip install dtaidistance--> assetId
-                if len(xref_keys) > 1:
-                    raise MqValueError('Cannot not specify more than one type of asset identifier')
-
-                definition = cls.get_definition(dataset_id)
-
-                sd = definition.dimensions.symbolDimensions
-                if definition.parameters.symbolStrategy == 'MDAPI' or ('assetId' not in sd and 'gsid' not in sd):
-                    xref_type = min(xref_keys)
-                    if asset_id_type is None:
-                        asset_id_type = xref_type
-
-                    xref_values = where[asset_id_type]
-                    xref_values = (xref_values,) if isinstance(xref_values, str) else xref_values
-                    asset_id_map = GsAssetApi.map_identifiers(xref_type, GsIdType.id, xref_values)
-
-                    if len(asset_id_map) != len(xref_values):
-                        raise MqValueError('Not all {} were resolved to asset Ids'.format(asset_id_type))
-
-                    setattr(query.where, xref_type, None)
-                    query.where.assetId = [asset_id_map[x] for x in xref_values]
-
         response: Union[DataQueryResponse, dict] = cls.execute_query(dataset_id, query)
-
-        results = cls.get_results(dataset_id, response, query)
-
-        if asset_id_type not in {GsIdType.id, None}:
-            asset_ids = tuple(set(filter(None, (r.get('assetId') for r in results))))
-            if asset_ids:
-                xref_map = GsAssetApi.map_identifiers(GsIdType.id, asset_id_type, asset_ids)
-
-                if len(xref_map) != len(asset_ids):
-                    raise MqValueError('Not all asset Ids were resolved to {}'.format(asset_id_type))
-
-                for result in results:
-                    result[asset_id_type] = xref_map[result['assetId']]
-
-        return results
+        return cls.get_results(dataset_id, response, query)
 
     @staticmethod
     def execute_query(dataset_id: str, query: Union[DataQuery, MDAPIDataQuery]):
@@ -332,17 +311,19 @@ class GsDataApi(DataApi):
 
     @staticmethod
     def build_market_data_query(asset_ids: List[str], query_type: QueryType, where: Union[FieldFilterMap, Dict] = None,
-                                source: Union[str] = None, real_time: bool = False):
+                                source: Union[str] = None, real_time: bool = False, measure='Curve'):
         inner = {
-            'assetIds': asset_ids,
+            'entityIds': asset_ids,
             'queryType': query_type.value,
             'where': where or {},
             'source': source or 'any',
             'frequency': 'Real Time' if real_time else 'End Of Day',
             'measures': [
-                'Curve'
+                measure
             ]
         }
+        if DataContext.current.interval is not None:
+            inner['interval'] = DataContext.current.interval
         if real_time:
             inner['startTime'] = DataContext.current.start_time
             inner['endTime'] = DataContext.current.end_time
@@ -354,10 +335,13 @@ class GsDataApi(DataApi):
         }
 
     @classmethod
-    def get_data_providers(cls, entity_id: str) -> Dict:
+    def get_data_providers(cls,
+                           entity_id: str,
+                           availability: Optional[Dict] = None) -> Dict:
         """Return daily and real-time data providers
 
         :param entity_id: identifier of entity i.e. asset, country, subdivision
+        :param availability: Optional Measures Availability response for the entity
         :return: dictionary of available data providers
 
         ** Usage **
@@ -365,48 +349,52 @@ class GsDataApi(DataApi):
         Return a dictionary containing a set of dataset providers for each available data field.
         For each field will return a dict of daily and real-time dataset providers where available.
         """
+        response = availability if availability else GsSession.current._get(f'/data/measures/{entity_id}/availability')
+        if 'errorMessages' in response:
+            raise MqValueError(f"Data availability request {response['requestId']} "
+                               f"failed: {response.get('errorMessages', '')}")
 
-        GsSession.current: GsSession
-        body = GsSession.current._get(f'/data/measures/{entity_id}/availability')
-        if 'errorMessages' in body:
-            raise MqValueError(f"data availablity request {body['requestId']} failed: {body.get('errorMessages', '')}")
-        if 'data' not in body:
-            providers = {}
-        else:
-            providers = {}
+        if 'data' not in response:
+            return {}
 
-            all_data_mappings = sorted(body['data'], key=lambda x: x['rank'], reverse=True)
+        providers = {}
+        all_data_mappings = sorted(response['data'], key=lambda x: x['rank'], reverse=True)
 
-            for source in all_data_mappings:
+        for source in all_data_mappings:
+            freq = source.get('frequency', 'End Of Day')
+            dataset_field = source.get('datasetField', '')
+            rank = source.get('rank')
 
-                freq = source.get('frequency', 'End Of Day')
-                dataset_field = source.get('datasetField', '')
-                rank = source.get('rank')
+            providers.setdefault(dataset_field, {})
 
-                providers.setdefault(dataset_field, {})
-
-                if rank:
-                    if freq == 'End Of Day':
-                        providers[dataset_field][DataFrequency.DAILY] = source['datasetId']
-                    elif freq == 'Real Time':
-                        providers[dataset_field][DataFrequency.REAL_TIME] = source['datasetId']
+            if rank:
+                if freq == 'End Of Day':
+                    providers[dataset_field][DataFrequency.DAILY] = source['datasetId']
+                elif freq == 'Real Time':
+                    providers[dataset_field][DataFrequency.REAL_TIME] = source['datasetId']
 
         return providers
 
     @classmethod
     def get_market_data(cls, query) -> pd.DataFrame:
         GsSession.current: GsSession
-        body = GsSession.current._post('/data/markets', payload=query)
-        container = body['responses'][0]['queryResponse'][0]
-        if 'errorMessages' in container:
-            raise MqValueError(f"market data request {body['requestId']} failed: {container['errorMessages']}")
-        if 'response' not in container:
-            df = MarketDataResponseFrame()
-        else:
-            df = MarketDataResponseFrame(container['response']['data'])
-            df.set_index('date' if 'date' in df.columns else 'time', inplace=True)
-            df.index = pd.to_datetime(df.index)
-        df.dataset_ids = tuple(container.get('dataSetIds', ()))
+        body = GsSession.current._post('/data/measures', payload=query)
+
+        ids = []
+        parts = []
+        for e in body['responses']:
+            container = e['queryResponse'][0]
+            ids.extend(container.get('dataSetIds', ()))
+            if 'errorMessages' in container:
+                raise MqValueError(f"measure service request {body['requestId']} failed: {container['errorMessages']}")
+            if 'response' in container:
+                df = MarketDataResponseFrame(container['response']['data'])
+                df.set_index('date' if 'date' in df.columns else 'time', inplace=True)
+                df.index = pd.to_datetime(df.index)
+                parts.append(df)
+
+        df = pd.concat(parts) if len(parts) > 0 else MarketDataResponseFrame()
+        df.dataset_ids = tuple(ids)
         return df
 
     @classmethod
@@ -652,8 +640,10 @@ class GsDataApi(DataApi):
         """
         if len(data):
             dataset_types = cls.get_types(dataset_id)
+            # Use first row to infer fields from data
+            incoming_data_data_types = pd.DataFrame([data[0]]).dtypes.to_dict()
 
-            df = pd.DataFrame(data, columns=dataset_types)
+            df = pd.DataFrame(data, columns={**dataset_types, **incoming_data_data_types})
 
             for field_name, type_name in dataset_types.items():
                 if df.get(field_name) is not None and type_name in ('date', 'date-time') and \
