@@ -14,14 +14,15 @@ specific language governing permissions and limitations
 under the License.
 """
 
-from typing import Union, Iterable
 import datetime
 
 from gs_quant.backtests.backtest_utils import *
-from gs_quant.backtests.generic_engine import BackTest
+from gs_quant.backtests.generic_engine import BackTest, ScalingPortfolio
 from gs_quant.base import Priceable
-from gs_quant.markets import HistoricalPricingContext, PricingContext
+from gs_quant.datetime.date import *
+from gs_quant.markets import HistoricalPricingContext
 from gs_quant.markets.portfolio import Portfolio
+from gs_quant.markets.securities import *
 
 action_count = 1
 
@@ -43,7 +44,7 @@ class HedgeActionRequirements(ActionRequirements):
 class Action(object):
     def __init__(self, name: str = None):
         self._needs_scaling = False
-        self._deterministic = True
+        self._calc_type = CalcType.simple
         self._risk = None
         global action_count
         if name is None:
@@ -61,9 +62,18 @@ class Action(object):
         """
         raise RuntimeError('apply_action must be implemented by subclass')
 
+    def raise_order(self, state: datetime.date, backtest: BackTest = None):
+        """
+        Get new trade orders
+        :param backtest:
+        :param state:
+        :return:
+        """
+        raise RuntimeError('raise_order must be implemented by subclass')
+
     @property
-    def deterministic(self):
-        return self._deterministic
+    def calc_type(self):
+        return self._calc_type
 
     @property
     def risk(self):
@@ -80,10 +90,9 @@ class AddTradeAction(Action):
                                trade will be added for all future dates
         :param name: optional additional name to the priceable name
         """
-        # TODO: make trade_duration capable of being a tenor or a date as well as a trade attribute
         super().__init__(name)
         self._priceables = make_list(priceables)
-        self._dated_priceables = {}  # a trigger may inject the portfolio at a trigger date
+        self._dated_priceables = {}
         self._trade_duration = trade_duration
         for i, p in enumerate(self._priceables):
             if p.name is None:
@@ -99,58 +108,62 @@ class AddTradeAction(Action):
     def trade_duration(self):
         return self._trade_duration
 
-    def apply_action(self, state: Union[datetime.date, Iterable[datetime.date]], backtest: BackTest):
+    def set_dated_priceables(self, state, priceables):
+        self._dated_priceables[state] = make_list(priceables)
+
+    def raise_order(self, state: Union[datetime.date, Iterable[datetime.date]], backtest: BackTest = None):
         with PricingContext(is_batch=True):
-            f = {}
+            orders = {}
             for s in state:
                 active_portfolio = self._dated_priceables.get(s) or self._priceables
                 with PricingContext(pricing_date=s):
-                    f[s] = Portfolio(active_portfolio).resolve(in_place=False)
+                    orders[s] = Portfolio(active_portfolio).resolve(in_place=False)
+        return orders
+
+    def apply_action(self, state: Union[datetime.date, Iterable[datetime.date]], backtest: BackTest):
+
+        orders = self.raise_order(state, backtest)
 
         for s in backtest.states:
             pos = []
-            for create_date, portfolio in f.items():
+            for create_date, portfolio in orders.items():
                 pos += [inst for inst in portfolio.result().instruments
                         if get_final_date(inst, create_date, self.trade_duration) >= s >= create_date]
-            backtest.portfolio_dict[s].append(pos)
+            if len(pos) > 0:
+                backtest.portfolio_dict[s].append(pos)
 
         return backtest
 
 
 class HedgeAction(Action):
-    def __init__(self, risk, priceables: Priceable, trade_duration: str = None, risks_on_final_day: bool = False,
+    def __init__(self, risk, priceables: Priceable = None, trade_duration: str = None, risks_on_final_day: bool = False,
                  name: str = None):
         super().__init__(name)
-        self._deterministic = False
+        self._calc_type = CalcType.semi_path_dependent
         self._priceable = priceables
         self._risk = risk
         self._trade_duration = trade_duration
         self._risks_on_final_day = risks_on_final_day
-        if self._priceable.name is None:
-            self._priceable.name = '{}_Pricable{}'.format(self._name, 0)
-        else:
-            self._priceable.name = '{}_{}'.format(self._name, self._priceable.name)
+        if priceables is not None:
+            if self._priceable.name is None:
+                self._priceable.name = '{}_Pricable{}'.format(self._name, 0)
+            else:
+                self._priceable.name = '{}_{}'.format(self._name, self._priceable.name)
 
     @property
     def trade_duration(self):
         return self._trade_duration
 
-    def apply_action(self, state: datetime.date, backtest: BackTest):
-        with PricingContext(pricing_date=state):
-            f = self._priceable.resolve(in_place=False)
-            hedge_delta = self._priceable.calc(self.risk)
-
-        hedge = f.result()
-        ratio = backtest.results[state][self.risk].aggregate() / hedge_delta.result()
-        hedge = scale_trade(hedge, ratio)
-
-        active_dates = [pricing_date for pricing_date in backtest.states if
-                        get_final_date(hedge, state, self.trade_duration) >= pricing_date >= state]
-        with HistoricalPricingContext(dates=active_dates):
+    def apply_action(self, state: Union[datetime.date, Iterable[datetime.date]], backtest: BackTest):
+        with HistoricalPricingContext(dates=make_list(state)):
             backtest.calc_calls += 1
-            backtest.calculations += len(active_dates) * len(backtest.risks)
-            hedge_res = Portfolio(hedge).calc(backtest.risks)
+            backtest.calculations += len(make_list(state))
+            f = Portfolio(make_list(self._priceable)).resolve(in_place=False)
 
-        for pricing_date in active_dates:
-            results = hedge_res[pricing_date]
-            backtest.add_results(pricing_date, results)
+        for create_date, portfolio in f.result().items():
+            active_dates = [s for s in backtest.states if get_final_date(portfolio.instruments[0], create_date,
+                                                                         self.trade_duration) >= s >= create_date]
+            backtest.scaling_portfolios[create_date].append(
+                ScalingPortfolio(trade=portfolio.instruments[0], dates=active_dates, risk=self.risk))
+
+        return backtest
