@@ -17,18 +17,19 @@ under the License.
 from copy import deepcopy
 from collections import defaultdict
 import pandas as pd
-
-from gs_quant.backtests.backtest_utils import make_list
+from typing import Optional
+from gs_quant.backtests.backtest_utils import make_list, CalcType
+from gs_quant.instrument import Instrument
 from gs_quant.markets.portfolio import Portfolio
-from gs_quant.markets import PricingContext
+from gs_quant.markets import PricingContext, HistoricalPricingContext
 from gs_quant.risk import RiskMeasure, Price
 from gs_quant.errors import MqValueError
-from typing import Optional
 
 
 class BackTest(object):
     def __init__(self, strategy, states, risks):
         self._portfolio_dict = defaultdict(Portfolio)
+        self._scaling_portfolios = defaultdict(list)  # list of ScalingPortfolio
         self._strategy = deepcopy(strategy)
         self._states = states
         self._results = defaultdict()
@@ -44,6 +45,14 @@ class BackTest(object):
     def portfolio_dict(self, portfolio_dict):
         self._portfolio_dict = portfolio_dict
 
+    @property
+    def scaling_portfolios(self):
+        return self._scaling_portfolios
+
+    @scaling_portfolios.setter
+    def scaling_portfolios(self, scaling_portfolios):
+        self._scaling_portfolios = scaling_portfolios
+
     @property
     def states(self):
         return self._states
@@ -57,7 +66,6 @@ class BackTest(object):
         return self._risks
 
     def add_results(self, date, results):
-        # TODO this may not work with portfolio risk results
         if date in self._results:
             self._results[date] += results
         else:
@@ -85,6 +93,14 @@ class BackTest(object):
         return pd.Series({d: i[risk].aggregate() for d, i in self._results.items()})
 
 
+class ScalingPortfolio(object):
+    def __init__(self, trade, dates, risk):
+        self.trade = trade
+        self.dates = dates
+        self.risk = risk
+        self.results = None
+
+
 class GenericEngine(object):
 
     @classmethod
@@ -99,11 +115,15 @@ class GenericEngine(object):
 
         backtest = BackTest(strategy, dates, risks)
 
+        if strategy.initial_portfolio is not None:
+            for date in dates:
+                backtest.portfolio_dict[date].append(strategy.initial_portfolio)
+
         for trigger in strategy.triggers:
-            if trigger.deterministic:
+            if trigger.calc_type != CalcType.path_dependent:
                 triggered_dates = [date for date in dates if trigger.has_triggered(date, backtest)]
                 for action in trigger.actions:
-                    if action.deterministic:
+                    if action.calc_type != CalcType.path_dependent:
                         action.apply_action(triggered_dates, backtest)
 
         with PricingContext(is_batch=True, show_progress=show_progress):
@@ -111,18 +131,38 @@ class GenericEngine(object):
                 with PricingContext(day):
                     backtest.calc_calls += 1
                     backtest.calculations += len(portfolio) * len(risks)
-                    backtest.add_results(day, portfolio.calc(risks[0] if len(risks) == 1 else tuple(risks)))
+                    backtest.add_results(day, portfolio.calc(tuple(risks)))
 
-        for trigger in strategy.triggers:
-            if not trigger.deterministic:
-                for date in dates:
+            # semi path dependent initial calc
+            for _, scaling_list in backtest.scaling_portfolios.items():
+                for p in scaling_list:
+                    with HistoricalPricingContext(dates=p.dates):
+                        backtest.calc_calls += 1
+                        backtest.calculations += len(p.dates) * len(risks)
+                        p.results = Portfolio([p.trade]).calc(tuple(risks))
+
+        for date in dates:
+            # semi path dependent scaling
+            if date in backtest.scaling_portfolios:
+                for p in backtest.scaling_portfolios[date]:
+                    scale_date = p.dates[0]
+                    scaling_factor = backtest.results[scale_date][p.risk][0] / p.results[scale_date][p.risk][0]
+                    scaled_trade = p.trade.as_dict()
+                    scaled_trade['notional_amount'] *= -scaling_factor
+                    scaled_trade = Instrument.from_dict(scaled_trade)
+                    for day in p.dates:
+                        backtest.add_results(day, p.results[day] * -scaling_factor)
+                        backtest.portfolio_dict[day] += Portfolio(scaled_trade)
+
+            # path dependent
+            for trigger in strategy.triggers:
+                if trigger.calc_type == CalcType.path_dependent:
                     if trigger.has_triggered(date, backtest):
                         for action in trigger.actions:
                             action.apply_action(date, backtest)
-            else:
-                for action in trigger.actions:
-                    if not action.deterministic:
-                        for date in dates:
+                else:
+                    for action in trigger.actions:
+                        if action.calc_type == CalcType.path_dependent:
                             if trigger.has_triggered(date, backtest):
                                 action.apply_action(date, backtest)
-        return backtest
+            return backtest
