@@ -20,8 +20,9 @@ from enum import Enum
 import pandas as pd
 
 from gs_quant.backtests.actions import Action
-from gs_quant.backtests.backtest_utils import make_list
+from gs_quant.backtests.backtest_utils import make_list, CalcType
 from gs_quant.backtests.generic_engine import BackTest
+import datetime as dt
 
 
 class TriggerDirection(Enum):
@@ -44,6 +45,14 @@ class PeriodicTriggerRequirements(TriggerRequirements):
         self.calendar = calendar
 
 
+class IntradayTriggerRequirements(TriggerRequirements):
+    def __init__(self, start_time, end_time, frequency):
+        super().__init__()
+        self.start_time = start_time
+        self.end_time = end_time
+        self.frequency = frequency
+
+
 class MktTriggerRequirements(TriggerRequirements):
     def __init__(self, data_source, trigger_level, direction):
         super().__init__()
@@ -73,7 +82,7 @@ class Trigger(object):
         self._trigger_requirements = trigger_requirements
         self._actions = make_list(actions)
         self._risks = [x.risk for x in self.actions if x.risk is not None]
-        self._deterministic = True
+        self._calc_type = CalcType.simple
 
     def has_triggered(self, state: datetime.date, backtest: BackTest = None) -> bool:
         """
@@ -85,8 +94,8 @@ class Trigger(object):
         raise RuntimeError('has_triggered to be implemented by subclass')
 
     @property
-    def deterministic(self):
-        return self._deterministic
+    def calc_type(self):
+        return self._calc_type
 
     @property
     def actions(self):
@@ -122,6 +131,30 @@ class PeriodicTrigger(Trigger):
         return state in self._trigger_dates
 
 
+class IntradayPeriodicTrigger(Trigger):
+    def __init__(self,
+                 trigger_requirements: IntradayTriggerRequirements,
+                 actions: Union[Action, Iterable[Action]]):
+        super().__init__(trigger_requirements, actions)
+
+        # generate all the trigger times
+        start = trigger_requirements.start_time
+        end = trigger_requirements.end_time
+        freq = trigger_requirements.frequency
+
+        self._trigger_times = []
+        time = start
+        while time <= end:
+            self._trigger_times.append(time)
+            time = (dt.datetime.combine(dt.date.today(), time) + dt.timedelta(minutes=freq)).time()
+
+    def get_trigger_times(self):
+        return self._trigger_times
+
+    def has_triggered(self, state: Union[datetime.date, datetime.datetime], backtest: BackTest = None) -> bool:
+        return state.time() in self._trigger_times
+
+
 class MktTrigger(Trigger):
     def __init__(self,
                  trigger_requirements: MktTriggerRequirements,
@@ -147,7 +180,7 @@ class StrategyRiskTrigger(Trigger):
                  trigger_requirements: RiskTriggerRequirements,
                  actions: Union[Action, Iterable[Action]]):
         super().__init__(trigger_requirements, actions)
-        self._deterministic = False
+        self._calc_type = CalcType.path_dependent
         self._risks += [trigger_requirements.risk]
 
     def has_triggered(self, state: datetime.date, backtest: BackTest = None) -> bool:
