@@ -24,6 +24,7 @@ from collections import namedtuple
 from enum import EnumMeta
 from functools import wraps
 from inspect import signature, Parameter
+import re
 from typing import Optional, Union, get_type_hints
 
 import inflection
@@ -39,12 +40,11 @@ _valid_date_formats = ('%Y-%m-%d',  # '2020-07-28'
                        '%d-%b-%y',  # '28-Jul-20'
                        '%d/%m/%Y')  # '28/07/2020
 
-
-def _normalise_arg(arg: str) -> str:
-    if keyword.iskeyword(arg) or arg in dir(builtins):
-        return arg + '_'
-    else:
-        return arg
+__builtins = set(dir(builtins))
+__iskeyword = keyword.iskeyword
+__getattribute__ = object.__getattribute__
+__setattr__ = object.__setattr__
+_underscore = inflection.underscore
 
 
 def camel_case_translate(f):
@@ -52,10 +52,11 @@ def camel_case_translate(f):
     def wrapper(*args, **kwargs):
         normalised_kwargs = {}
         for arg, value in kwargs.items():
-            arg = _normalise_arg(arg)
+            if arg in __builtins or __iskeyword(arg):
+                arg += '_'
 
             if not arg.isupper():
-                snake_case_arg = inflection.underscore(arg)
+                snake_case_arg = _underscore(arg)
                 if snake_case_arg != arg:
                     if snake_case_arg in kwargs:
                         raise ValueError('{} and {} both specified'.format(arg, snake_case_arg))
@@ -71,11 +72,12 @@ def camel_case_translate(f):
     return wrapper
 
 
-class RiskKey(namedtuple('RiskKey', ('provider', 'date', 'market', 'params', 'scenario', 'risk_measure'))):
+def do_not_resolve(func):
+    func.do_not_resolve = True
+    return func
 
-    @property
-    def ex_date_and_market(self):
-        return RiskKey(self.provider, None, None, self.params, self.scenario, self.risk_measure)
+
+class RiskKey(namedtuple('RiskKey', ('provider', 'date', 'market', 'params', 'scenario', 'risk_measure'))):
 
     @property
     def ex_measure(self):
@@ -92,6 +94,9 @@ class EnumBase:
     def _missing_(cls: EnumMeta, key):
         return next((m for m in cls.__members__.values() if m.value.lower() == key.lower()), None)
 
+    def __reduce_ex__(self, protocol):
+        return self.__class__, (self.value,)
+
     def __lt__(self: EnumMeta, other):
         return self.value < other.value
 
@@ -112,22 +117,29 @@ class Base(metaclass=ABCMeta):
             pass
 
     def __getattr__(self, item):
-        snake_case_item = inflection.underscore(item)
-        if snake_case_item in super().__getattribute__('properties')():
-            return super().__getattribute__(snake_case_item)
+        properties = __getattribute__(self, 'properties')()
+
+        if item.startswith('_') or item == 'name' or item in properties:
+            return __getattribute__(self, item)
+
+        snake_case_item = _underscore(item)
+        if snake_case_item in properties:
+            return __getattribute__(self, snake_case_item)
         else:
-            return super().__getattribute__(item)
+            return __getattribute__(self, item)
 
     def __setattr__(self, key, value):
-        properties = super().__getattribute__('properties')()
-        snake_case_key = inflection.underscore(key)
-        key_is_property = key in properties
-        snake_case_key_is_property = snake_case_key in properties
+        properties = __getattribute__(self, 'properties')()
 
-        if snake_case_key_is_property and not key_is_property:
-            return super().__setattr__(snake_case_key, value)
+        if key.startswith('_') or key == 'name' or key in properties:
+            return __setattr__(self, key, value)
+
+        snake_case_key = inflection.underscore(key)
+
+        if snake_case_key in properties:
+            return __setattr__(self, snake_case_key, value)
         else:
-            return super().__setattr__(key, value)
+            return __setattr__(self, key, value)
 
     def __repr__(self):
         if self.name is not None:
@@ -147,7 +159,7 @@ class Base(metaclass=ABCMeta):
         if not self._hash_is_calced:
             calced_hash = hash(self.name)
             for prop in self.properties():
-                value = super().__getattribute__(prop)
+                value = __getattribute__(self, prop)
                 if isinstance(value, dict):
                     value = tuple(value.items())
                 elif isinstance(value, list):
@@ -162,8 +174,7 @@ class Base(metaclass=ABCMeta):
         return \
             type(self) == type(other) and (self.name is None or other.name is None or self.name == other.name) and \
             (self.__calced_hash is None or other.__calced_hash is None or self.__calced_hash == other.__calced_hash) \
-            and all(super(Base, self).__getattribute__(p) == super(Base, other).__getattribute__(p)
-                    for p in self.properties())
+            and all(__getattribute__(self, p) == __getattribute__(other, p) for p in self.properties())
 
     def __ne__(self, other) -> bool:
         return not self.__eq__(other)
@@ -173,8 +184,8 @@ class Base(metaclass=ABCMeta):
             return type(self).__name__ < type(other).__name__
 
         for prop in itertools.chain(('name',), sorted(self.properties())):
-            val = super(Base, self).__getattribute__(prop)
-            other_val = super(Base, other).__getattribute__(prop)
+            val = __getattribute__(self, prop)
+            other_val = __getattribute__(other, prop)
 
             if val != other_val:
                 if val is None:
@@ -219,11 +230,14 @@ class Base(metaclass=ABCMeta):
 
     def as_dict(self, as_camel_case: bool = False) -> dict:
         """Dictionary of the public, non-null properties and values"""
+        name_mappings = getattr(self, '_name_mappings', {})
+
         if not self.__as_dict[as_camel_case]:
             raw_properties = self.properties()
-            properties = (inflection.camelize(p, uppercase_first_letter=False) for p in raw_properties) \
+            properties = (name_mappings[p] if p in name_mappings else
+                          inflection.camelize(p, uppercase_first_letter=False) for p in raw_properties) \
                 if as_camel_case else raw_properties
-            values = (super(Base, self).__getattribute__(p) for p in raw_properties)
+            values = (__getattribute__(self, p) for p in raw_properties)
             self.__as_dict[as_camel_case] = dict((p, v) for p, v in zip(properties, values) if v is not None)
 
         return copy.copy(self.__as_dict[as_camel_case])
@@ -270,11 +284,14 @@ class Base(metaclass=ABCMeta):
         return item_type
 
     def __from_dict(self, values: dict):
+        name_mappings = getattr(self, '_name_mappings', {})
+
         for prop in self.properties():
             if getattr(type(self), prop).fset is None:
                 continue
 
-            prop_value = values.get(prop, values.get(inflection.camelize(prop, uppercase_first_letter=False)))
+            prop_value = values.get(name_mappings.get(prop, prop),
+                                    values.get(inflection.camelize(prop, uppercase_first_letter=False)))
 
             if prop_value is not None:
                 if isinstance(prop_value, np.generic):
@@ -400,9 +417,29 @@ class Base(metaclass=ABCMeta):
             raise ValueError('Can only use from_instance with an object of the same type')
 
         for prop in self.properties():
-            attr = getattr(super().__getattribute__('__class__'), prop)
+            attr = getattr(__getattribute__(self, '__class__'), prop)
             if attr.fset:
-                super(Base, self).__setattr__(prop, super(Base, instance).__getattribute__(prop))
+                __setattr__(self, prop, __getattribute__(instance, prop))
+
+    def to_json(self) -> dict:
+        return {re.sub('_$', '', k): v for k, v in self.as_dict(as_camel_case=True).items()}
+
+
+class TypeMixin(metaclass=ABCMeta):
+
+    @property
+    @abstractmethod
+    def _type(self) -> str:
+        ...
+
+    def to_json(self) -> dict:
+        ret = super().to_json()
+        ret['$type'] = self._type
+        return ret
+
+
+class TypedBase(TypeMixin, Base):
+    pass
 
 
 class Priceable(Base, metaclass=ABCMeta):
@@ -581,13 +618,15 @@ class InstrumentBase(Base):
             self.__unresolved = None
 
 
-class QuotableBuilder(Base, metaclass=ABCMeta):
+class QuotableBuilder(TypeMixin):
 
     def __init__(self, valuation_overrides: Optional[dict] = None):
         super().__init__()
         self.valuation_overrides = valuation_overrides
 
     @property
+    @do_not_resolve
+    @do_not_serialise
     def valuation_overrides(self) -> Optional[dict]:
         return self.__valuation_overrides
 
@@ -595,9 +634,22 @@ class QuotableBuilder(Base, metaclass=ABCMeta):
     def valuation_overrides(self, value: dict):
         self.__valuation_overrides = value
 
+    def to_json(self):
+        ret = {'properties': TypeMixin.to_json(self)}
+        ret['$type'] = ret['properties'].pop('$type')
+
+        if self.__valuation_overrides:
+            ret['valuationOverrides'] = self.__valuation_overrides
+
+        return ret
+
 
 class Market(Base):
-    pass
+
+    @property
+    @abstractmethod
+    def location(self):
+        ...
 
 
 class Sentinel:
