@@ -24,6 +24,7 @@ from typing import Optional, Tuple, Union, Dict
 import cachetools
 import pandas as pd
 import pytz
+from pydash import get
 
 from gs_quant.api.gs.assets import GsAssetApi, GsAsset, AssetClass, AssetParameters, \
     AssetType as GsAssetType, PositionSet, Currency
@@ -99,6 +100,12 @@ class AssetType(Enum):
     #: Commodity Reference Price
     COMMODITY_REFERENCE_PRICE = "Commodity Reference Price"
 
+    # COMMODITY NATURAL GAS Hub
+    COMMODITY_NATURAL_GAS_HUB = "Commodity Natural Gas Hub"
+
+    # COMMODITY EU NATURAL GAS Hub
+    COMMODITY_EU_NATURAL_GAS_HUB = "Commodity EU Natural Gas Hub"
+
     #: Commodity Power Node
     COMMODITY_POWER_NODE = "Commodity Power Node"
 
@@ -117,6 +124,9 @@ class AssetType(Enum):
     #: Commodity
     COMMODITY = "Commodity"
 
+    #: Crypto
+    CRYPTOCURRENCY = "Cryptocurrency"
+
 
 class AssetIdentifier(EntityIdentifier):
     """Asset type enumeration
@@ -133,6 +143,8 @@ class AssetIdentifier(EntityIdentifier):
     ISIN = "ISIN"  #: International Securities Identification Number (US38141G1040)
     SEDOL = "SEDOL"  #: LSE Stock Exchange Daily Official List code (2407966)
     TICKER = "TICKER"  #: Exchange ticker (GS)
+    PLOT_ID = "PLOT_ID"  #: ID for Marquee PlotTool
+    GSID = "GSID"
 
 
 class ReturnType(Enum):
@@ -518,6 +530,58 @@ class CommodityReferencePrice(Asset):
         return AssetType.COMMODITY_REFERENCE_PRICE
 
 
+class CommodityNaturalGasHub(Asset):
+    """Commodity Natural Gas Hub
+
+    Represents a distinct location in commodity Natural Gas markets
+
+    """
+
+    def __init__(self,
+                 id_: str,
+                 name: str,
+                 entity: Optional[Dict] = None):
+        Asset.__init__(self, id_, AssetClass.Commod, name, entity=entity)
+
+    def get_type(self) -> AssetType:
+        return AssetType.COMMODITY_NATURAL_GAS_HUB
+
+
+class CommodityEUNaturalGasHub(Asset):
+    """Commodity EU Natural Gas Hub
+
+    Represents a virtual/physical hub in EU Natural Gas markets
+
+    """
+
+    def __init__(self,
+                 id_: str,
+                 name: str,
+                 entity: Optional[Dict] = None):
+        Asset.__init__(self, id_, AssetClass.Commod, name, entity=entity)
+
+    def get_type(self) -> AssetType:
+        return AssetType.COMMODITY_EU_NATURAL_GAS_HUB
+
+
+class Cryptocurrency(Asset):
+    """Cryptocurrency
+
+    Represents a cryptocurrency
+
+    """
+
+    def __init__(self,
+                 id_: str,
+                 asset_class: Union[AssetClass, str],
+                 name: str,
+                 entity: Optional[Dict] = None):
+        Asset.__init__(self, id_, asset_class, name, entity=entity)
+
+    def get_type(self) -> AssetType:
+        return AssetType.CRYPTOCURRENCY
+
+
 class CommodityPowerNode(Asset):
     """Commodity Power Node
 
@@ -860,6 +924,12 @@ class SecurityMaster:
         if asset_type in (GsAssetType.CommodityReferencePrice.value,):
             return CommodityReferencePrice(gs_asset.id, gs_asset.name, entity=asset_entity)
 
+        if asset_type in (GsAssetType.CommodityNaturalGasHub.value,):
+            return CommodityNaturalGasHub(gs_asset.id, gs_asset.name, entity=asset_entity)
+
+        if asset_type in (GsAssetType.CommodityEUNaturalGasHub.value,):
+            return CommodityEUNaturalGasHub(gs_asset.id, gs_asset.name, entity=asset_entity)
+
         if asset_type in (GsAssetType.CommodityPowerNode.value,):
             return CommodityPowerNode(gs_asset.id, gs_asset.name, entity=asset_entity)
 
@@ -873,10 +943,14 @@ class SecurityMaster:
             return Commodity(gs_asset.id, gs_asset.name, entity=asset_entity)
 
         if asset_type in (GsAssetType.FutureMarket.value,):
-            return FutureMarket(gs_asset.id, gs_asset.name, entity=asset_entity)
+            return FutureMarket(gs_asset.id, gs_asset.assetClass, gs_asset.name, entity=asset_entity)
 
         if asset_type in (GsAssetType.FutureContract.value,):
-            return FutureContract(gs_asset.id, gs_asset.name, entity=asset_entity)
+            return FutureContract(gs_asset.id, gs_asset.assetClass, gs_asset.name, entity=asset_entity)
+
+        # workaround as casing is being migrated
+        if asset_type == GsAssetType.Cryptocurrency.value:
+            return Cryptocurrency(gs_asset.id, gs_asset.assetClass, gs_asset.name, entity=asset_entity)
 
         raise TypeError(f'unsupported asset type {asset_type}')
 
@@ -959,9 +1033,8 @@ class SecurityMaster:
             query['type'] = [t.value for t in cls.__asset_type_to_gs_types(asset_type)]
 
         if sort_by_rank:
-            results = GsAssetApi.get_many_assets(as_of=as_of, return_type=dict, **query)
-            results = sorted(results, key=lambda d: d.get('rank', 0), reverse=True)
-            result = next(iter(results), None)
+            results = GsAssetApi.get_many_assets(as_of=as_of, return_type=dict, order_by=['>rank'], **query)
+            result = get(results, '0')
 
             if result:
                 result = GsAsset.from_dict(result)
