@@ -16,7 +16,7 @@ under the License.
 
 from gs_quant.target.common import *
 import datetime
-from typing import Tuple, Union
+from typing import Mapping, Tuple, Union
 from enum import Enum
 from gs_quant.base import Base, EnumBase, InstrumentBase, camel_case_translate, get_enum_value
 
@@ -202,7 +202,7 @@ class ClassificationConstraint(Base):
 
 class FactorConstraint(Base):
         
-    """Constraint on a specific axioma factor."""
+    """Constraint on a specific risk model factor."""
 
     @camel_case_translate
     def __init__(
@@ -218,7 +218,7 @@ class FactorConstraint(Base):
 
     @property
     def factor(self) -> str:
-        """Axioma factor name."""
+        """Risk model factor name."""
         return self.__factor
 
     @factor.setter
@@ -255,7 +255,7 @@ class FactorExposure(Base):
 
     @property
     def factor(self) -> str:
-        """Name of the Axioma factor."""
+        """Name of the Risk Model factor."""
         return self.__factor
 
     @factor.setter
@@ -274,162 +274,6 @@ class FactorExposure(Base):
         self.__exposure = value        
 
 
-class HedgeBenchmark(Base):
-        
-    @camel_case_translate
-    def __init__(
-        self,
-        asset_id: str,
-        cumulative_pnl: Tuple[Tuple[Union[datetime.date, float], ...], ...] = None,
-        name: str = None
-    ):        
-        super().__init__()
-        self.asset_id = asset_id
-        self.cumulative_pnl = cumulative_pnl
-        self.name = name
-
-    @property
-    def asset_id(self) -> str:
-        """Marquee unique asset identifier."""
-        return self.__asset_id
-
-    @asset_id.setter
-    def asset_id(self, value: str):
-        self._property_changed('asset_id')
-        self.__asset_id = value        
-
-    @property
-    def cumulative_pnl(self) -> Tuple[Tuple[Union[datetime.date, float], ...], ...]:
-        """An array of tuples that represent values in a time series."""
-        return self.__cumulative_pnl
-
-    @cumulative_pnl.setter
-    def cumulative_pnl(self, value: Tuple[Tuple[Union[datetime.date, float], ...], ...]):
-        self._property_changed('cumulative_pnl')
-        self.__cumulative_pnl = value        
-
-
-class HedgeConstituent(Base):
-        
-    """Fields returned for each hedge constituent."""
-
-    @camel_case_translate
-    def __init__(
-        self,
-        asset_id: str,
-        name: str,
-        weight: float,
-        currency: Union[Currency, str],
-        country: str = None,
-        correlation: float = None,
-        transaction_cost: float = None,
-        marginal_cost: float = None,
-        borrow_cost: float = None
-    ):        
-        super().__init__()
-        self.asset_id = asset_id
-        self.name = name
-        self.weight = weight
-        self.currency = currency
-        self.country = country
-        self.correlation = correlation
-        self.transaction_cost = transaction_cost
-        self.marginal_cost = marginal_cost
-        self.borrow_cost = borrow_cost
-
-    @property
-    def asset_id(self) -> str:
-        """Marquee unique asset identifier."""
-        return self.__asset_id
-
-    @asset_id.setter
-    def asset_id(self, value: str):
-        self._property_changed('asset_id')
-        self.__asset_id = value        
-
-    @property
-    def name(self) -> str:
-        """Display name of the asset"""
-        return self.__name
-
-    @name.setter
-    def name(self, value: str):
-        self._property_changed('name')
-        self.__name = value        
-
-    @property
-    def weight(self) -> float:
-        """Weight of the constituent."""
-        return self.__weight
-
-    @weight.setter
-    def weight(self, value: float):
-        self._property_changed('weight')
-        self.__weight = value        
-
-    @property
-    def currency(self) -> Union[Currency, str]:
-        """Currency, ISO 4217 currency code or exchange quote modifier (e.g. GBP vs GBp)"""
-        return self.__currency
-
-    @currency.setter
-    def currency(self, value: Union[Currency, str]):
-        self._property_changed('currency')
-        self.__currency = get_enum_value(Currency, value)        
-
-    @property
-    def country(self) -> str:
-        """Country name of asset."""
-        return self.__country
-
-    @country.setter
-    def country(self, value: str):
-        self._property_changed('country')
-        self.__country = value        
-
-    @property
-    def correlation(self) -> float:
-        """Max 44 day rolling correlation between the constituent and target returns."""
-        return self.__correlation
-
-    @correlation.setter
-    def correlation(self, value: float):
-        self._property_changed('correlation')
-        self.__correlation = value        
-
-    @property
-    def transaction_cost(self) -> float:
-        """The estimated market impact cost for trading a position or set of positions at a
-           specified market participation rate or trade-out period."""
-        return self.__transaction_cost
-
-    @transaction_cost.setter
-    def transaction_cost(self, value: float):
-        self._property_changed('transaction_cost')
-        self.__transaction_cost = value        
-
-    @property
-    def marginal_cost(self) -> float:
-        """The estimated market impact cost multiplied by the position's gross weight in
-           the portfolio."""
-        return self.__marginal_cost
-
-    @marginal_cost.setter
-    def marginal_cost(self, value: float):
-        self._property_changed('marginal_cost')
-        self.__marginal_cost = value        
-
-    @property
-    def borrow_cost(self) -> float:
-        """The estimated borrow cost in bps for a position or position set."""
-        return self.__borrow_cost
-
-    @borrow_cost.setter
-    def borrow_cost(self, value: float):
-        self._property_changed('borrow_cost')
-        self.__borrow_cost = value        
-
-
 class HedgerComparisonProperties(Base):
         
     """properties used to hedge the comparison."""
@@ -466,43 +310,6 @@ class HedgerComparisonProperties(Base):
         self.__hedge_value = value        
 
 
-class Target(Base):
-        
-    """The asset id, portfolio id, or set of positions that make up the hedge target."""
-
-    @camel_case_translate
-    def __init__(
-        self,
-        id_: str = None,
-        positions: Tuple[Position, ...] = None,
-        name: str = None
-    ):        
-        super().__init__()
-        self.__id = id_
-        self.positions = positions
-        self.name = name
-
-    @property
-    def id(self) -> str:
-        """Marquee unique identifier"""
-        return self.__id
-
-    @id.setter
-    def id(self, value: str):
-        self._property_changed('id')
-        self.__id = value        
-
-    @property
-    def positions(self) -> Tuple[Position, ...]:
-        """Array of quantity position objects."""
-        return self.__positions
-
-    @positions.setter
-    def positions(self, value: Tuple[Position, ...]):
-        self._property_changed('positions')
-        self.__positions = value        
-
-
 class FactorExposures(Base):
         
     """Breakdown of factor exposures by category."""
@@ -824,66 +631,222 @@ class FactorHedgerConstraintPrioritySettings(Base):
         self.__sector_exposures = get_enum_value(HedgerConstraintPrioritySetting, value)        
 
 
-class PerformanceHedgeResult(Base):
+class HedgeConstituent(Base):
         
-    """Result of a performance replication hedge."""
+    """Fields returned for each hedge constituent."""
 
     @camel_case_translate
     def __init__(
         self,
-        target: dict,
-        hedge: dict = None,
-        hedged_target: dict = None,
-        benchmarks: Tuple[dict, ...] = None,
-        name: str = None
+        asset_id: str,
+        name: str,
+        weight: float,
+        currency: Union[Currency, str],
+        country: str = None,
+        correlation: float = None,
+        transaction_cost: float = None,
+        marginal_cost: float = None,
+        borrow_cost: float = None,
+        shares: float = None,
+        price: float = None,
+        multiplier: float = None,
+        notional: float = None,
+        bbid: str = None,
+        adv_percentage: float = None,
+        sector: str = None,
+        industry: str = None
     ):        
         super().__init__()
-        self.target = target
-        self.hedge = hedge
-        self.hedged_target = hedged_target
-        self.benchmarks = benchmarks
+        self.asset_id = asset_id
         self.name = name
+        self.weight = weight
+        self.currency = currency
+        self.country = country
+        self.correlation = correlation
+        self.transaction_cost = transaction_cost
+        self.marginal_cost = marginal_cost
+        self.borrow_cost = borrow_cost
+        self.shares = shares
+        self.price = price
+        self.multiplier = multiplier
+        self.notional = notional
+        self.bbid = bbid
+        self.adv_percentage = adv_percentage
+        self.sector = sector
+        self.industry = industry
 
     @property
-    def target(self) -> dict:
-        """Statistics of the target."""
-        return self.__target
+    def asset_id(self) -> str:
+        """Marquee unique asset identifier."""
+        return self.__asset_id
 
-    @target.setter
-    def target(self, value: dict):
-        self._property_changed('target')
-        self.__target = value        
+    @asset_id.setter
+    def asset_id(self, value: str):
+        self._property_changed('asset_id')
+        self.__asset_id = value        
 
     @property
-    def hedge(self) -> dict:
-        """Statistics of the portfolio of assets making up the hedge."""
-        return self.__hedge
+    def name(self) -> str:
+        """Display name of the asset"""
+        return self.__name
 
-    @hedge.setter
-    def hedge(self, value: dict):
-        self._property_changed('hedge')
-        self.__hedge = value        
+    @name.setter
+    def name(self, value: str):
+        self._property_changed('name')
+        self.__name = value        
 
     @property
-    def hedged_target(self) -> dict:
-        """Statistics of the portfolio resulting from combining the target and hedge
-           portfolios."""
-        return self.__hedged_target
+    def weight(self) -> float:
+        """Weight of the constituent."""
+        return self.__weight
 
-    @hedged_target.setter
-    def hedged_target(self, value: dict):
-        self._property_changed('hedged_target')
-        self.__hedged_target = value        
+    @weight.setter
+    def weight(self, value: float):
+        self._property_changed('weight')
+        self.__weight = value        
 
     @property
-    def benchmarks(self) -> Tuple[dict, ...]:
-        """Benchmarks compared against the target."""
-        return self.__benchmarks
+    def currency(self) -> Union[Currency, str]:
+        """Currency, ISO 4217 currency code or exchange quote modifier (e.g. GBP vs GBp)"""
+        return self.__currency
 
-    @benchmarks.setter
-    def benchmarks(self, value: Tuple[dict, ...]):
-        self._property_changed('benchmarks')
-        self.__benchmarks = value        
+    @currency.setter
+    def currency(self, value: Union[Currency, str]):
+        self._property_changed('currency')
+        self.__currency = get_enum_value(Currency, value)        
+
+    @property
+    def country(self) -> str:
+        """Country name of asset."""
+        return self.__country
+
+    @country.setter
+    def country(self, value: str):
+        self._property_changed('country')
+        self.__country = value        
+
+    @property
+    def correlation(self) -> float:
+        """Max 44 day rolling correlation between the constituent and target returns."""
+        return self.__correlation
+
+    @correlation.setter
+    def correlation(self, value: float):
+        self._property_changed('correlation')
+        self.__correlation = value        
+
+    @property
+    def transaction_cost(self) -> float:
+        """The estimated market impact cost for trading a position or set of positions at a
+           specified market participation rate or trade-out period."""
+        return self.__transaction_cost
+
+    @transaction_cost.setter
+    def transaction_cost(self, value: float):
+        self._property_changed('transaction_cost')
+        self.__transaction_cost = value        
+
+    @property
+    def marginal_cost(self) -> float:
+        """The estimated market impact cost multiplied by the position's gross weight in
+           the portfolio."""
+        return self.__marginal_cost
+
+    @marginal_cost.setter
+    def marginal_cost(self, value: float):
+        self._property_changed('marginal_cost')
+        self.__marginal_cost = value        
+
+    @property
+    def borrow_cost(self) -> float:
+        """The estimated borrow fee in bps to short the position or position set."""
+        return self.__borrow_cost
+
+    @borrow_cost.setter
+    def borrow_cost(self, value: float):
+        self._property_changed('borrow_cost')
+        self.__borrow_cost = value        
+
+    @property
+    def shares(self) -> float:
+        """The quantity of shares."""
+        return self.__shares
+
+    @shares.setter
+    def shares(self, value: float):
+        self._property_changed('shares')
+        self.__shares = value        
+
+    @property
+    def price(self) -> float:
+        """The price in USD."""
+        return self.__price
+
+    @price.setter
+    def price(self, value: float):
+        self._property_changed('price')
+        self.__price = value        
+
+    @property
+    def multiplier(self) -> float:
+        """Underlying unit per asset multiplier"""
+        return self.__multiplier
+
+    @multiplier.setter
+    def multiplier(self, value: float):
+        self._property_changed('multiplier')
+        self.__multiplier = value        
+
+    @property
+    def notional(self) -> float:
+        """Notional of the position"""
+        return self.__notional
+
+    @notional.setter
+    def notional(self, value: float):
+        self._property_changed('notional')
+        self.__notional = value        
+
+    @property
+    def bbid(self) -> str:
+        """Bloomberg Id Identifier"""
+        return self.__bbid
+
+    @bbid.setter
+    def bbid(self, value: str):
+        self._property_changed('bbid')
+        self.__bbid = value        
+
+    @property
+    def adv_percentage(self) -> float:
+        """Percentage of the constituent's notional in the hedge to it's average daily
+           dollar volume."""
+        return self.__adv_percentage
+
+    @adv_percentage.setter
+    def adv_percentage(self, value: float):
+        self._property_changed('adv_percentage')
+        self.__adv_percentage = value        
+
+    @property
+    def sector(self) -> str:
+        """GICS Sector classification (level 1)."""
+        return self.__sector
+
+    @sector.setter
+    def sector(self, value: str):
+        self._property_changed('sector')
+        self.__sector = value        
+
+    @property
+    def industry(self) -> str:
+        """GICS industry classification (level 3)."""
+        return self.__industry
+
+    @industry.setter
+    def industry(self, value: str):
+        self._property_changed('industry')
+        self.__industry = value        
 
 
 class FactorHedgerResultPositions(Base):
@@ -1045,7 +1008,7 @@ class FactorHedgerResultPositions(Base):
 
     @property
     def borrow_cost_bps(self) -> float:
-        """The estimated borrow cost in bps for a position or position set."""
+        """The estimated borrow fee in bps to short the position or position set."""
         return self.__borrow_cost_bps
 
     @borrow_cost_bps.setter
@@ -1055,7 +1018,7 @@ class FactorHedgerResultPositions(Base):
 
     @property
     def volatility(self) -> float:
-        """Standard deviation of the annualized returns."""
+        """Annualized ex-ante risk a percentage of your portfolio's notional."""
         return self.__volatility
 
     @volatility.setter
@@ -1155,6 +1118,103 @@ class FactorHedgerResultPositions(Base):
         self.__total_pnl = value        
 
 
+class HedgeBenchmark(Base):
+        
+    @camel_case_translate
+    def __init__(
+        self,
+        asset_id: str,
+        cumulative_pnl: Tuple[Tuple[Union[datetime.date, float], ...], ...] = None,
+        name: str = None
+    ):        
+        super().__init__()
+        self.asset_id = asset_id
+        self.cumulative_pnl = cumulative_pnl
+        self.name = name
+
+    @property
+    def asset_id(self) -> str:
+        """Marquee unique asset identifier."""
+        return self.__asset_id
+
+    @asset_id.setter
+    def asset_id(self, value: str):
+        self._property_changed('asset_id')
+        self.__asset_id = value        
+
+    @property
+    def cumulative_pnl(self) -> Tuple[Tuple[Union[datetime.date, float], ...], ...]:
+        """An array of tuples that represent values in a time series."""
+        return self.__cumulative_pnl
+
+    @cumulative_pnl.setter
+    def cumulative_pnl(self, value: Tuple[Tuple[Union[datetime.date, float], ...], ...]):
+        self._property_changed('cumulative_pnl')
+        self.__cumulative_pnl = value        
+
+
+class PerformanceHedgeResult(Base):
+        
+    """Result of a performance replication hedge."""
+
+    @camel_case_translate
+    def __init__(
+        self,
+        target: dict,
+        hedge: dict = None,
+        hedged_target: dict = None,
+        benchmarks: Tuple[dict, ...] = None,
+        name: str = None
+    ):        
+        super().__init__()
+        self.target = target
+        self.hedge = hedge
+        self.hedged_target = hedged_target
+        self.benchmarks = benchmarks
+        self.name = name
+
+    @property
+    def target(self) -> dict:
+        """Statistics of the target."""
+        return self.__target
+
+    @target.setter
+    def target(self, value: dict):
+        self._property_changed('target')
+        self.__target = value        
+
+    @property
+    def hedge(self) -> dict:
+        """Statistics of the portfolio of assets making up the hedge."""
+        return self.__hedge
+
+    @hedge.setter
+    def hedge(self, value: dict):
+        self._property_changed('hedge')
+        self.__hedge = value        
+
+    @property
+    def hedged_target(self) -> dict:
+        """Statistics of the portfolio resulting from combining the target and hedge
+           portfolios."""
+        return self.__hedged_target
+
+    @hedged_target.setter
+    def hedged_target(self, value: dict):
+        self._property_changed('hedged_target')
+        self.__hedged_target = value        
+
+    @property
+    def benchmarks(self) -> Tuple[dict, ...]:
+        """Benchmarks compared against the target."""
+        return self.__benchmarks
+
+    @benchmarks.setter
+    def benchmarks(self, value: Tuple[dict, ...]):
+        self._property_changed('benchmarks')
+        self.__benchmarks = value        
+
+
 class FactorHedgeResult(Base):
         
     """Result of a hedge calculation with an objective to minimize factor risk."""
@@ -1265,6 +1325,43 @@ class HedgerComparison(Base):
         self.__result = value        
 
 
+class Target(Base):
+        
+    """The asset id, portfolio id, or set of positions that make up the hedge target."""
+
+    @camel_case_translate
+    def __init__(
+        self,
+        id_: str = None,
+        positions: Tuple[Position, ...] = None,
+        name: str = None
+    ):        
+        super().__init__()
+        self.__id = id_
+        self.positions = positions
+        self.name = name
+
+    @property
+    def id(self) -> str:
+        """Marquee unique identifier"""
+        return self.__id
+
+    @id.setter
+    def id(self, value: str):
+        self._property_changed('id')
+        self.__id = value        
+
+    @property
+    def positions(self) -> Tuple[Position, ...]:
+        """Array of quantity position objects."""
+        return self.__positions
+
+    @positions.setter
+    def positions(self, value: Tuple[Position, ...]):
+        self._property_changed('positions')
+        self.__positions = value        
+
+
 class FactorHedgeParameters(Base):
         
     """Parameters for a hedge calculation to minimize factor risk."""
@@ -1435,7 +1532,9 @@ class FactorHedgeParameters(Base):
 
     @property
     def exclude_corporate_actions(self) -> bool:
-        """Exclude assets pending for corporate actions from being in the hedge"""
+        """Exclude assets pending for corporate actions from being in the hedge. Default
+           corporate action types excluded are Merges, Quote lot adjustments,
+           Rights, Spinoffs, and Reorganizations."""
         return self.__exclude_corporate_actions
 
     @exclude_corporate_actions.setter
@@ -1559,7 +1658,7 @@ class FactorHedgeParameters(Base):
     @property
     def market_participation_rate(self) -> float:
         """Maximum market participation rate used to estimate the cost of trading a
-           portfolio of stocks."""
+           portfolio of stocks. This does not effect the optimization."""
         return self.__market_participation_rate
 
     @market_participation_rate.setter
@@ -1579,7 +1678,7 @@ class FactorHedgeParameters(Base):
 
     @property
     def factor_constraints(self) -> Tuple[FactorConstraint, ...]:
-        """Constraints to be applied to specific axioma factors in the hedge."""
+        """Constraints to be applied to specific risk model factors in the hedge."""
         return self.__factor_constraints
 
     @factor_constraints.setter
@@ -1907,7 +2006,7 @@ class PerformanceHedgeParameters(Base):
     @property
     def market_participation_rate(self) -> float:
         """Maximum market participation rate used to estimate the cost of trading a
-           portfolio of stocks."""
+           portfolio of stocks. This does not effect the optimization."""
         return self.__market_participation_rate
 
     @market_participation_rate.setter
@@ -1993,7 +2092,6 @@ class Hedge(Base):
         last_updated_by_id: str = None,
         last_updated_time: datetime.datetime = None,
         entitlements: Entitlements = None,
-        entitlement_exclusions: EntitlementExclusions = None,
         tags: Tuple[str, ...] = None,
         description: str = None,
         objective: Union[HedgeObjective, str] = None,
@@ -2008,7 +2106,6 @@ class Hedge(Base):
         self.last_updated_by_id = last_updated_by_id
         self.last_updated_time = last_updated_time
         self.entitlements = entitlements
-        self.entitlement_exclusions = entitlement_exclusions
         self.tags = tags
         self.name = name
         self.description = description
@@ -2087,16 +2184,6 @@ class Hedge(Base):
         self._property_changed('entitlements')
         self.__entitlements = value        
 
-    @property
-    def entitlement_exclusions(self) -> EntitlementExclusions:
-        """Defines the exclusion entitlements of a given resource."""
-        return self.__entitlement_exclusions
-
-    @entitlement_exclusions.setter
-    def entitlement_exclusions(self, value: EntitlementExclusions):
-        self._property_changed('entitlement_exclusions')
-        self.__entitlement_exclusions = value        
-
     @property
     def tags(self) -> Tuple[str, ...]:
         """Metadata associated with the object. Provide an array of strings which will be
