@@ -16,40 +16,11 @@ under the License.
 
 from gs_quant.target.common import *
 import datetime
-from typing import Tuple, Union
+from typing import Mapping, Tuple, Union
 from enum import Enum
 from gs_quant.base import Base, EnumBase, InstrumentBase, camel_case_translate, get_enum_value
 
 
-class AssetProperties(EnumBase, Enum):    
-    
-    """Enum listing supported asset properties"""
-
-    assetClass = 'assetClass'
-    currency = 'currency'
-    createdTime = 'createdTime'
-    description = 'description'
-    exchange = 'exchange'
-    id = 'id'
-    liveDate = 'liveDate'
-    name = 'name'
-    underliers = 'underliers'
-    region = 'region'
-    shortName = 'shortName'
-    type = 'type'
-    xref_bbid = 'xref.bbid'
-    xref_bcid = 'xref.bcid'
-    xref_ticker = 'xref.ticker'
-    xref_ric = 'xref.ric'
-    date = 'date'
-    value = 'value'
-    slope = 'slope'
-    OIS_value = 'OIS value'
-    
-    def __repr__(self):
-        return self.value
-
-
 class AvailableUnitTypes(EnumBase, Enum):    
     
     """Enum listing supported unit types"""
@@ -116,6 +87,7 @@ class ParameterRender(EnumBase, Enum):
     sparkline = 'sparkline'
     stackedBarChart = 'stackedBarChart'
     text = 'text'
+    treemap = 'treemap'
     triColor = 'triColor'
     
     def __repr__(self):
@@ -224,79 +196,6 @@ class ColumnProperty(Base):
         self.__property = value        
 
 
-class ExportParameters(Base):
-        
-    """Object with properties specifying how to export individual row or complete
-       monitor data."""
-
-    @camel_case_translate
-    def __init__(
-        self,
-        tokens: Tuple[str, ...],
-        data_set_id: str = None,
-        fields: Tuple[str, ...] = None,
-        label: str = None,
-        start_date: str = None,
-        name: str = None
-    ):        
-        super().__init__()
-        self.data_set_id = data_set_id
-        self.fields = fields
-        self.label = label
-        self.start_date = start_date
-        self.tokens = tokens
-        self.name = name
-
-    @property
-    def data_set_id(self) -> str:
-        """Id of the DataSet in which the export will retrieve data from."""
-        return self.__data_set_id
-
-    @data_set_id.setter
-    def data_set_id(self, value: str):
-        self._property_changed('data_set_id')
-        self.__data_set_id = value        
-
-    @property
-    def fields(self) -> Tuple[str, ...]:
-        """The fields to be exported from the DataSet."""
-        return self.__fields
-
-    @fields.setter
-    def fields(self, value: Tuple[str, ...]):
-        self._property_changed('fields')
-        self.__fields = value        
-
-    @property
-    def label(self) -> str:
-        """The label for the export button. For example: Export Historical Data."""
-        return self.__label
-
-    @label.setter
-    def label(self, value: str):
-        self._property_changed('label')
-        self.__label = value        
-
-    @property
-    def start_date(self) -> str:
-        """The relative start date for the history of data to retrieve. Eg: -1y."""
-        return self.__start_date
-
-    @start_date.setter
-    def start_date(self, value: str):
-        self._property_changed('start_date')
-        self.__start_date = value        
-
-    @property
-    def tokens(self) -> Tuple[str, ...]:
-        return self.__tokens
-
-    @tokens.setter
-    def tokens(self, value: Tuple[str, ...]):
-        self._property_changed('tokens')
-        self.__tokens = value        
-
-
 class FieldMap(Base):
         
     @camel_case_translate
@@ -677,6 +576,79 @@ class ColumnOperation(Base):
         self.__parameters = value        
 
 
+class ExportParameters(Base):
+        
+    """Object with properties specifying how to export individual row or complete
+       monitor data."""
+
+    @camel_case_translate
+    def __init__(
+        self,
+        tokens: Tuple[str, ...],
+        data_set_id: str = None,
+        fields: Tuple[str, ...] = None,
+        label: str = None,
+        start_date: str = None,
+        name: str = None
+    ):        
+        super().__init__()
+        self.data_set_id = data_set_id
+        self.fields = fields
+        self.label = label
+        self.start_date = start_date
+        self.tokens = tokens
+        self.name = name
+
+    @property
+    def data_set_id(self) -> str:
+        """Id of the DataSet in which the export will retrieve data from."""
+        return self.__data_set_id
+
+    @data_set_id.setter
+    def data_set_id(self, value: str):
+        self._property_changed('data_set_id')
+        self.__data_set_id = value        
+
+    @property
+    def fields(self) -> Tuple[str, ...]:
+        """The fields to be exported from the DataSet."""
+        return self.__fields
+
+    @fields.setter
+    def fields(self, value: Tuple[str, ...]):
+        self._property_changed('fields')
+        self.__fields = value        
+
+    @property
+    def label(self) -> str:
+        """The label for the export button. For example: Export Historical Data."""
+        return self.__label
+
+    @label.setter
+    def label(self, value: str):
+        self._property_changed('label')
+        self.__label = value        
+
+    @property
+    def start_date(self) -> str:
+        """The relative start date for the history of data to retrieve. Eg: -1y."""
+        return self.__start_date
+
+    @start_date.setter
+    def start_date(self, value: str):
+        self._property_changed('start_date')
+        self.__start_date = value        
+
+    @property
+    def tokens(self) -> Tuple[str, ...]:
+        return self.__tokens
+
+    @tokens.setter
+    def tokens(self, value: Tuple[str, ...]):
+        self._property_changed('tokens')
+        self.__tokens = value        
+
+
 class Function(Base):
         
     """Function or Measure to be applied to the column."""
@@ -1050,7 +1022,7 @@ class ColumnDefinition(Base):
         render: Union[ParameterRender, str],
         name: str,
         enable_cell_flashing: bool = None,
-        entity_property: Union[AssetProperties, str] = None,
+        entity_property: str = None,
         function: Function = None,
         format_: ColumnFormat = None,
         width: float = None,
@@ -1062,7 +1034,9 @@ class ColumnDefinition(Base):
         end_date: str = None,
         tooltip: str = None,
         parent_column_name: str = None,
-        primary: bool = None
+        primary: bool = None,
+        pivots: Tuple[str, ...] = None,
+        disable_cell_tooltips: bool = None
     ):        
         super().__init__()
         self.enable_cell_flashing = enable_cell_flashing
@@ -1081,6 +1055,8 @@ class ColumnDefinition(Base):
         self.tooltip = tooltip
         self.parent_column_name = parent_column_name
         self.primary = primary
+        self.pivots = pivots
+        self.disable_cell_tooltips = disable_cell_tooltips
 
     @property
     def enable_cell_flashing(self) -> bool:
@@ -1113,14 +1089,15 @@ class ColumnDefinition(Base):
         self.__render = get_enum_value(ParameterRender, value)        
 
     @property
-    def entity_property(self) -> Union[AssetProperties, str]:
-        """Property to fetch from an entity"""
+    def entity_property(self) -> str:
+        """Property to fetch from an entity like assetClass, id, xref.ric,
+           parameters.strike etc."""
         return self.__entity_property
 
     @entity_property.setter
-    def entity_property(self, value: Union[AssetProperties, str]):
+    def entity_property(self, value: str):
         self._property_changed('entity_property')
-        self.__entity_property = get_enum_value(AssetProperties, value)        
+        self.__entity_property = value        
 
     @property
     def function(self) -> Function:
@@ -1242,6 +1219,26 @@ class ColumnDefinition(Base):
         self._property_changed('primary')
         self.__primary = value        
 
+    @property
+    def pivots(self) -> Tuple[str, ...]:
+        """Array of columns to pivot. Specifically for treemap component."""
+        return self.__pivots
+
+    @pivots.setter
+    def pivots(self, value: Tuple[str, ...]):
+        self._property_changed('pivots')
+        self.__pivots = value        
+
+    @property
+    def disable_cell_tooltips(self) -> bool:
+        """Whether or not to disable cell tooltips."""
+        return self.__disable_cell_tooltips
+
+    @disable_cell_tooltips.setter
+    def disable_cell_tooltips(self, value: bool):
+        self._property_changed('disable_cell_tooltips')
+        self.__disable_cell_tooltips = value        
+
 
 class EntityId(Base):
         
@@ -1253,12 +1250,14 @@ class EntityId(Base):
         id_: str = None,
         column_mappings: Tuple[ColumnMappings, ...] = None,
         color: str = None,
+        route_url: str = None,
         name: str = None
     ):        
         super().__init__()
         self.__id = id_
         self.column_mappings = column_mappings
         self.color = color
+        self.route_url = route_url
         self.name = name
 
     @property
@@ -1291,11 +1290,23 @@ class EntityId(Base):
         self._property_changed('color')
         self.__color = value        
 
+    @property
+    def route_url(self) -> str:
+        """The url to route to, when the row is clicked on"""
+        return self.__route_url
+
+    @route_url.setter
+    def route_url(self, value: str):
+        self._property_changed('route_url')
+        self.__route_url = value        
+
 
 class RatesResponseData(Base):
         
     """Rates calculated response data."""
 
+    _name_mappings = {'libor_id': 'libor_id'}
+
     @camel_case_translate
     def __init__(
         self,
@@ -1436,6 +1447,9 @@ class MonitorParameters(Base):
         row_groups: Tuple[RowGroup, ...],
         export: ExportParameters = None,
         ignore_business_day_logic: bool = None,
+        horizontal_scroll: bool = None,
+        mid_value_average: bool = None,
+        aggregate_queries: bool = None,
         name: str = None
     ):        
         super().__init__()
@@ -1443,6 +1457,9 @@ class MonitorParameters(Base):
         self.row_groups = row_groups
         self.export = export
         self.ignore_business_day_logic = ignore_business_day_logic
+        self.horizontal_scroll = horizontal_scroll
+        self.mid_value_average = mid_value_average
+        self.aggregate_queries = aggregate_queries
         self.name = name
 
     @property
@@ -1486,6 +1503,38 @@ class MonitorParameters(Base):
         self._property_changed('ignore_business_day_logic')
         self.__ignore_business_day_logic = value        
 
+    @property
+    def horizontal_scroll(self) -> bool:
+        """Whether or not the monitor has a horizontal scroll on the UI if the monitor does
+           not fit the screen."""
+        return self.__horizontal_scroll
+
+    @horizontal_scroll.setter
+    def horizontal_scroll(self, value: bool):
+        self._property_changed('horizontal_scroll')
+        self.__horizontal_scroll = value        
+
+    @property
+    def mid_value_average(self) -> bool:
+        """Whether or not the midColor value for heatmaps should be the average value
+           instead of 0."""
+        return self.__mid_value_average
+
+    @mid_value_average.setter
+    def mid_value_average(self, value: bool):
+        self._property_changed('mid_value_average')
+        self.__mid_value_average = value        
+
+    @property
+    def aggregate_queries(self) -> bool:
+        """Whether or not to aggregate queries for direct to dataset columns."""
+        return self.__aggregate_queries
+
+    @aggregate_queries.setter
+    def aggregate_queries(self, value: bool):
+        self._property_changed('aggregate_queries')
+        self.__aggregate_queries = value        
+
 
 class Monitor(Base):
         
