@@ -16,7 +16,7 @@ under the License.
 
 from gs_quant.target.common import *
 import datetime
-from typing import Tuple, Union
+from typing import Mapping, Tuple, Union
 from enum import Enum
 from gs_quant.base import Base, EnumBase, InstrumentBase, camel_case_translate, get_enum_value
 
@@ -33,6 +33,7 @@ class MqexsAssetClass(EnumBase, Enum):
     Earon = 'Earon'
     FICC = 'FICC'
     Prime = 'Prime'
+    IOI = 'IOI'
     
     def __repr__(self):
         return self.value
