@@ -21,6 +21,8 @@ from .statistics import *
 from .econometrics import *
 from .technicals import *
 from .measures import *
+from .measures_countries import *
+from .measures_portfolios import *
 from .measures_rates import *
 from .helper import *
 from .backtesting import *
