@@ -13,15 +13,20 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
+import datetime
 import inspect
 import logging
 from enum import Enum, IntEnum
 from functools import wraps
-from typing import Optional, Union, List
+from typing import Optional, Union, List, Iterable
 
 import pandas as pd
 
 from gs_quant.api.gs.data import QueryType
+from gs_quant.data import DataContext
+from gs_quant.datetime.relative_date import RelativeDate
+from gs_quant.entities.entity import EntityType
+from gs_quant.errors import MqValueError
 
 
 def _create_enum(name, members):
@@ -36,7 +41,7 @@ def _to_offset(tenor: str) -> pd.DateOffset:
     import re
     matcher = re.fullmatch('(\\d+)([dwmy])', tenor)
     if not matcher:
-        raise ValueError('invalid tenor ' + tenor)
+        raise MqValueError('invalid tenor ' + tenor)
 
     ab = matcher.group(2)
     if ab == 'd':
@@ -60,7 +65,6 @@ CurveType = _create_enum('CurveType', ['prices', 'excess_returns'])
 
 
 class Window:
-
     """
     Create a Window with size and ramp up to use.
 
@@ -75,7 +79,7 @@ class Window:
 
     **Examples**
 
-    Window size is :math:`22` obversations and the ramp up value is :math:`10`:
+    Window size is :math:`22` observations and the ramp up value is :math:`10`:
 
     >>> Window(22, 10)
 
@@ -89,13 +93,23 @@ class Window:
         self.w = w
         self.r = w if r is None else r
 
+    def as_dict(self):
+        return {
+            'w': self.w,
+            'r': self.r
+        }
+
+    @classmethod
+    def from_dict(cls, obj):
+        return Window(w=obj.get('w'), r=obj.get('r'))
+
 
 def _check_window(series_length: int, window: Window):
     if series_length > 0 and isinstance(window.w, int) and isinstance(window.r, int):
         if window.w <= 0:
-            raise ValueError('Window value must be greater than zero.')
+            raise MqValueError('Window value must be greater than zero.')
         if window.r > series_length or window.r < 0:
-            raise ValueError('Ramp value must be less than the length of the series and greater than zero.')
+            raise MqValueError('Ramp value must be less than the length of the series and greater than zero.')
 
 
 def apply_ramp(x: pd.Series, window: Window) -> pd.Series:
@@ -144,8 +158,17 @@ def plot_session_function(fn):
     return fn
 
 
+def check_forward_looking(pricing_date, source, name="function"):
+    if pricing_date is not None or source != 'plottool':
+        return
+    if DataContext.current.end_date <= datetime.date.today():
+        msg = (f'{name}() requires a forward looking date range e.g. [0d, 3y]. '
+               'Please update the date range via the date picker.')
+        raise MqValueError(msg)
+
+
 def plot_measure(asset_class: Optional[tuple] = None, asset_type: Optional[tuple] = None,
-                 dependencies: Optional[List[QueryType]] = []):
+                 dependencies: Optional[List[QueryType]] = tuple()):
     # Indicates that fn should be exported to plottool as a member function / pseudo-measure.
     # Set category to None for no restrictions, else provide a tuple of allowed values.
     def decorator(fn):
@@ -153,6 +176,7 @@ def plot_measure(asset_class: Optional[tuple] = None, asset_type: Optional[tuple
         assert asset_type is None or isinstance(asset_type, tuple)
 
         fn.plot_measure = True
+        fn.entity_type = EntityType.ASSET
         fn.asset_class = asset_class
         fn.asset_type = asset_type
         fn.dependencies = dependencies
@@ -162,6 +186,22 @@ def plot_measure(asset_class: Optional[tuple] = None, asset_type: Optional[tuple
     return decorator
 
 
+def plot_measure_entity(entity_type: EntityType, dependencies: Optional[Iterable[QueryType]] = tuple()):
+    def decorator(fn):
+        assert isinstance(entity_type, EntityType)
+        if dependencies is not None:
+            assert isinstance(dependencies, Iterable)
+            assert all(isinstance(x, QueryType) for x in dependencies)
+
+        fn.plot_measure_entity = True
+        fn.entity_type = entity_type
+        fn.dependencies = tuple(dependencies)  # immutable
+
+        return fn
+
+    return decorator
+
+
 def plot_method(fn):
     # Indicates that fn should be exported to plottool as a method.
     fn.plot_method = True
@@ -188,3 +228,30 @@ def log_return(logger: logging.Logger, message):
         return inner
 
     return outer
+
+
+def get_df_with_retries(fetcher, start_date, end_date, exchange, retries=1):
+    """
+    Loads results from Data Service by calling fetcher function. Shifts query date range back by business days until
+    result is not empty or retry limit reached. This is a fallback feature in case a data upload is late. Measure
+    implementations should be written such that retries are usually not required.
+
+    :param fetcher: a no-argument function runs a data query and returns a DataFrame
+    :param start_date: initial start date for query
+    :param end_date: initial end date for query
+    :param exchange: exchange to use for holiday calendar
+    :param retries: maximum number of retries
+    :return: DataFrame
+    """
+    retries = max(retries, 0)
+    while retries > -1:
+        with DataContext(start_date, end_date):
+            result = fetcher()
+        if not result.empty:
+            break
+        kwargs = {'exchanges': [exchange]} if exchange else {}
+        # no need to include any part of the previous date range since it's known to be empty
+        end_date = RelativeDate('-1b', base_date=start_date).apply_rule(**kwargs)
+        start_date = end_date
+        retries -= 1
+    return result
