@@ -256,6 +256,9 @@ def _match_floating_tenors(swap_args) -> dict:
 
 
 def _get_tdapi_rates_assets(allow_many=False, **kwargs) -> Union[str, list]:
+    # sanitize input for asset query.
+    if("pricing_location" in kwargs):
+        del kwargs["pricing_location"]
     assets = GsAssetApi.get_many_assets(**kwargs)
     # change order of basis swap legs and check if swap in dataset
     if len(assets) == 0 and ('asset_parameters_payer_rate_option' in kwargs):  # flip legs
@@ -401,8 +404,8 @@ def _get_swap_data(asset: Asset, swap_tenor: str, benchmark_type: str = None, fl
                    forward_tenor: Optional[GENERIC_DATE] = None, clearing_house: _ClearingHouse = None,
                    source: str = None, real_time: bool = False,
                    query_type: QueryType = QueryType.SWAP_RATE) -> pd.DataFrame:
-    if real_time:
-        raise NotImplementedError('realtime swap_rate not implemented')
+    if real_time and not (query_type == QueryType.SWAP_RATE):
+        raise NotImplementedError('realtime swap_rate not implemented for anything but rates')
     currency = CurrencyEnum(asset.get_identifier(AssetIdentifier.BLOOMBERG_ID))
 
     if currency.value not in CURRENCY_TO_SWAP_RATE_BENCHMARK.keys():
@@ -736,11 +739,11 @@ def _get_swaption_measure(asset: Asset, benchmark_type: str = None, floating_rat
                           source: str = None, real_time: bool = False, allow_many: bool = False,
                           query_type: QueryType = QueryType.SWAPTION_PREMIUM) -> Series:
     if real_time:
-        raise NotImplementedError('realtime swap_rate not implemented')
+        raise NotImplementedError(f'realtime {query_type.value} not implemented')
     currency = CurrencyEnum(asset.get_identifier(AssetIdentifier.BLOOMBERG_ID))
 
     if not swaptions_defaults_provider.is_supported(currency):
-        raise NotImplementedError('Data not available for {} swap rates'.format(currency.value))
+        raise NotImplementedError(f'Data not available for {currency.value} {query_type.value}')
 
     query = _swaption_build_asset_query(currency, benchmark_type, effective_date, expiration_tenor, floating_rate_tenor,
                                         strike_reference, termination_tenor, clearing_house)
